pub struct Member {
pub name: String,
pub content: Range<usize>,
}Expand description
A member of the archive, and the byte range of its stored content.
The name is the entry’s path within the archive, which is the value the
uri field of the corresponding collection entry takes.
Fields
name: Stringcontent: Range<usize>Trait Implementations
impl Eq for Member
impl StructuralPartialEq for Member